Module interactive

Module interactive 

Functions

choose_entry
Choose a single entry from a list using fzf (if available) or a dialoguer fallback.
has_fzf
select_entries
Select multiple entries from a list using a dialoguer multi-select menu.